from django.apps import AppConfig

class PayheroDjangoConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'payhero_django'
    verbose_name = "Django PayHero Integration"